[SCM] Samba Shared Repository - branch master updated

Volker Lendecke vlendec at samba.org
Sat Sep 16 06:36:02 UTC 2017


The branch, master has been updated
       via  2a003b1 lib: tevent: Remove select backend.
      from  e5a2e62 wafsamba: We need to honor DESTDIR in INSTALL_DIR

https://git.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit 2a003b1a576dcbbba0d60bae90427776a5c27867
Author: Jeremy Allison <jra at samba.org>
Date:   Tue Sep 12 12:08:38 2017 -0700

    lib: tevent: Remove select backend.
    
    select() is no longer useful on modern systems.
    
    Signed-off-by: Jeremy Allison <jra at samba.org>
    Reviewed-by: Volker Lendecke <vl at samba.org>
    
    Autobuild-User(master): Volker Lendecke <vl at samba.org>
    Autobuild-Date(master): Sat Sep 16 08:35:39 CEST 2017 on sn-devel-144

-----------------------------------------------------------------------

Summary of changes:
 lib/tevent/tevent.c          |   1 -
 lib/tevent/tevent_internal.h |   1 -
 lib/tevent/tevent_select.c   | 280 -------------------------------------------
 lib/tevent/wscript           |   2 +-
 source3/selftest/tests.py    |   2 +-
 source3/torture/torture.c    |  10 +-
 6 files changed, 7 insertions(+), 289 deletions(-)
 delete mode 100644 lib/tevent/tevent_select.c


Changeset truncated at 500 lines:

diff --git a/lib/tevent/tevent.c b/lib/tevent/tevent.c
index 5f44b03..a2d2003 100644
--- a/lib/tevent/tevent.c
+++ b/lib/tevent/tevent.c
@@ -128,7 +128,6 @@ static void tevent_backend_init(void)
 
 	done = true;
 
-	tevent_select_init();
 	tevent_poll_init();
 	tevent_poll_mt_init();
 #if defined(HAVE_EPOLL)
diff --git a/lib/tevent/tevent_internal.h b/lib/tevent/tevent_internal.h
index a5f1ebde..47ea39b 100644
--- a/lib/tevent/tevent_internal.h
+++ b/lib/tevent/tevent_internal.h
@@ -377,7 +377,6 @@ int tevent_common_check_signal(struct tevent_context *ev);
 void tevent_cleanup_pending_signal_handlers(struct tevent_signal *se);
 
 bool tevent_standard_init(void);
-bool tevent_select_init(void);
 bool tevent_poll_init(void);
 void tevent_poll_event_add_fd_internal(struct tevent_context *ev,
 				       struct tevent_fd *fde);
diff --git a/lib/tevent/tevent_select.c b/lib/tevent/tevent_select.c
deleted file mode 100644
index 55dd0b6..0000000
--- a/lib/tevent/tevent_select.c
+++ /dev/null
@@ -1,280 +0,0 @@
-/* 
-   Unix SMB/CIFS implementation.
-   main select loop and event handling
-   Copyright (C) Andrew Tridgell	2003-2005
-   Copyright (C) Stefan Metzmacher	2005-2009
-
-     ** NOTE! The following LGPL license applies to the tevent
-     ** library. This does NOT imply that all of Samba is released
-     ** under the LGPL
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Lesser General Public
-   License as published by the Free Software Foundation; either
-   version 3 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Lesser General Public License for more details.
-
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, see <http://www.gnu.org/licenses/>.
-*/
-
-#include "replace.h"
-#include "system/filesys.h"
-#include "system/select.h"
-#include "tevent.h"
-#include "tevent_util.h"
-#include "tevent_internal.h"
-
-struct select_event_context {
-	/* a pointer back to the generic event_context */
-	struct tevent_context *ev;
-
-	/* the maximum file descriptor number in fd_events */
-	int maxfd;
-};
-
-/*
-  create a select_event_context structure.
-*/
-static int select_event_context_init(struct tevent_context *ev)
-{
-	struct select_event_context *select_ev;
-
-	/*
-	 * We might be called during tevent_re_initialise()
-	 * which means we need to free our old additional_data.
-	 */
-	TALLOC_FREE(ev->additional_data);
-
-	select_ev = talloc_zero(ev, struct select_event_context);
-	if (!select_ev) return -1;
-	select_ev->ev = ev;
-
-	ev->additional_data = select_ev;
-	return 0;
-}
-
-/*
-  recalculate the maxfd
-*/
-static void calc_maxfd(struct select_event_context *select_ev)
-{
-	struct tevent_fd *fde;
-
-	select_ev->maxfd = 0;
-	for (fde = select_ev->ev->fd_events; fde; fde = fde->next) {
-		if (fde->fd > select_ev->maxfd) {
-			select_ev->maxfd = fde->fd;
-		}
-	}
-}
-
-
-/* to mark the ev->maxfd invalid
- * this means we need to recalculate it
- */
-#define EVENT_INVALID_MAXFD (-1)
-
-/*
-  destroy an fd_event
-*/
-static int select_event_fd_destructor(struct tevent_fd *fde)
-{
-	struct tevent_context *ev = fde->event_ctx;
-	struct select_event_context *select_ev = NULL;
-
-	if (ev) {
-		select_ev = talloc_get_type_abort(ev->additional_data,
-						  struct select_event_context);
-
-		if (select_ev->maxfd == fde->fd) {
-			select_ev->maxfd = EVENT_INVALID_MAXFD;
-		}
-	}
-
-	return tevent_common_fd_destructor(fde);
-}
-
-/*
-  add a fd based event
-  return NULL on failure (memory allocation error)
-*/
-static struct tevent_fd *select_event_add_fd(struct tevent_context *ev, TALLOC_CTX *mem_ctx,
-					     int fd, uint16_t flags,
-					     tevent_fd_handler_t handler,
-					     void *private_data,
-					     const char *handler_name,
-					     const char *location)
-{
-	struct select_event_context *select_ev =
-		talloc_get_type_abort(ev->additional_data,
-		struct select_event_context);
-	struct tevent_fd *fde;
-
-	if (fd < 0 || fd >= FD_SETSIZE) {
-		errno = EBADF;
-		return NULL;
-	}
-
-	fde = tevent_common_add_fd(ev, mem_ctx, fd, flags,
-				   handler, private_data,
-				   handler_name, location);
-	if (!fde) return NULL;
-
-	if ((select_ev->maxfd != EVENT_INVALID_MAXFD)
-	    && (fde->fd > select_ev->maxfd)) {
-		select_ev->maxfd = fde->fd;
-	}
-	talloc_set_destructor(fde, select_event_fd_destructor);
-
-	return fde;
-}
-
-/*
-  event loop handling using select()
-*/
-static int select_event_loop_select(struct select_event_context *select_ev, struct timeval *tvalp)
-{
-	fd_set r_fds, w_fds;
-	struct tevent_fd *fde;
-	int selrtn;
-	int select_errno;
-
-	/* we maybe need to recalculate the maxfd */
-	if (select_ev->maxfd == EVENT_INVALID_MAXFD) {
-		calc_maxfd(select_ev);
-	}
-
-	FD_ZERO(&r_fds);
-	FD_ZERO(&w_fds);
-
-	/* setup any fd events */
-	for (fde = select_ev->ev->fd_events; fde; fde = fde->next) {
-		if (fde->fd < 0 || fde->fd >= FD_SETSIZE) {
-			tevent_debug(select_ev->ev, TEVENT_DEBUG_FATAL,
-				     "ERROR: EBADF fd[%d] >= %d "
-				     "select_event_loop_once\n",
-				     fde->fd, FD_SETSIZE);
-			errno = EBADF;
-			return -1;
-		}
-
-		if (fde->flags & TEVENT_FD_READ) {
-			FD_SET(fde->fd, &r_fds);
-		}
-		if (fde->flags & TEVENT_FD_WRITE) {
-			FD_SET(fde->fd, &w_fds);
-		}
-	}
-
-	if (select_ev->ev->signal_events &&
-	    tevent_common_check_signal(select_ev->ev)) {
-		return 0;
-	}
-
-	tevent_trace_point_callback(select_ev->ev, TEVENT_TRACE_BEFORE_WAIT);
-	selrtn = select(select_ev->maxfd+1, &r_fds, &w_fds, NULL, tvalp);
-	select_errno = errno;
-	tevent_trace_point_callback(select_ev->ev, TEVENT_TRACE_AFTER_WAIT);
-
-	if (selrtn == -1 && select_errno == EINTR &&
-	    select_ev->ev->signal_events) {
-		tevent_common_check_signal(select_ev->ev);
-		return 0;
-	}
-
-	if (selrtn == -1 && select_errno == EBADF) {
-		/* the socket is dead! this should never
-		   happen as the socket should have first been
-		   made readable and that should have removed
-		   the event, so this must be a bug. This is a
-		   fatal error. */
-		tevent_debug(select_ev->ev, TEVENT_DEBUG_FATAL,
-			     "ERROR: EBADF on select_event_loop_once\n");
-		errno = select_errno;
-		return -1;
-	}
-
-	if (selrtn == 0 && tvalp) {
-		/* we don't care about a possible delay here */
-		tevent_common_loop_timer_delay(select_ev->ev);
-		return 0;
-	}
-
-	if (selrtn > 0) {
-		/* at least one file descriptor is ready - check
-		   which ones and call the handler, being careful to allow
-		   the handler to remove itself when called */
-		for (fde = select_ev->ev->fd_events; fde; fde = fde->next) {
-			uint16_t flags = 0;
-
-			if (FD_ISSET(fde->fd, &r_fds) && (fde->flags & TEVENT_FD_READ)) {
-				flags |= TEVENT_FD_READ;
-			}
-			if (FD_ISSET(fde->fd, &w_fds) && (fde->flags & TEVENT_FD_WRITE)) {
-				flags |= TEVENT_FD_WRITE;
-			}
-			if (flags) {
-				DLIST_DEMOTE(select_ev->ev->fd_events, fde);
-				fde->handler(select_ev->ev, fde, flags, fde->private_data);
-				break;
-			}
-		}
-	}
-
-	return 0;
-}
-
-/*
-  do a single event loop using the events defined in ev 
-*/
-static int select_event_loop_once(struct tevent_context *ev, const char *location)
-{
-	struct select_event_context *select_ev =
-		talloc_get_type_abort(ev->additional_data,
-		struct select_event_context);
-	struct timeval tval;
-
-	if (ev->signal_events &&
-	    tevent_common_check_signal(ev)) {
-		return 0;
-	}
-
-	if (ev->threaded_contexts != NULL) {
-		tevent_common_threaded_activate_immediate(ev);
-	}
-
-	if (ev->immediate_events &&
-	    tevent_common_loop_immediate(ev)) {
-		return 0;
-	}
-
-	tval = tevent_common_loop_timer_delay(ev);
-	if (tevent_timeval_is_zero(&tval)) {
-		return 0;
-	}
-
-	return select_event_loop_select(select_ev, &tval);
-}
-
-static const struct tevent_ops select_event_ops = {
-	.context_init		= select_event_context_init,
-	.add_fd			= select_event_add_fd,
-	.set_fd_close_fn	= tevent_common_fd_set_close_fn,
-	.get_fd_flags		= tevent_common_fd_get_flags,
-	.set_fd_flags		= tevent_common_fd_set_flags,
-	.add_timer		= tevent_common_add_timer_v2,
-	.schedule_immediate	= tevent_common_schedule_immediate,
-	.add_signal		= tevent_common_add_signal,
-	.loop_once		= select_event_loop_once,
-	.loop_wait		= tevent_common_loop_wait,
-};
-
-_PRIVATE_ bool tevent_select_init(void)
-{
-	return tevent_register_backend("select", &select_event_ops);
-}
diff --git a/lib/tevent/wscript b/lib/tevent/wscript
index bc874bb..9188073 100644
--- a/lib/tevent/wscript
+++ b/lib/tevent/wscript
@@ -77,7 +77,7 @@ def build(bld):
     bld.RECURSE('lib/talloc')
 
     SRC = '''tevent.c tevent_debug.c tevent_fd.c tevent_immediate.c
-             tevent_queue.c tevent_req.c tevent_select.c
+             tevent_queue.c tevent_req.c
              tevent_poll.c tevent_threads.c
              tevent_signal.c tevent_standard.c tevent_timed.c tevent_util.c tevent_wakeup.c'''
 
diff --git a/source3/selftest/tests.py b/source3/selftest/tests.py
index 7bb0e51..139bba0 100755
--- a/source3/selftest/tests.py
+++ b/source3/selftest/tests.py
@@ -133,7 +133,7 @@ local_tests = [
     "LOCAL-sid_to_string",
     "LOCAL-binary_to_sid",
     "LOCAL-DBTRANS",
-    "LOCAL-TEVENT-SELECT",
+    "LOCAL-TEVENT-POLL",
     "LOCAL-CONVERT-STRING",
     "LOCAL-CONV-AUTH-INFO",
     "LOCAL-IDMAP-TDB-COMMON",
diff --git a/source3/torture/torture.c b/source3/torture/torture.c
index 636eef0..4667517 100644
--- a/source3/torture/torture.c
+++ b/source3/torture/torture.c
@@ -11114,17 +11114,17 @@ static bool run_local_dbtrans(int dummy)
 
 /*
  * Just a dummy test to be run under a debugger. There's no real way
  * to inspect the tevent_select specific function from outside of
  * tevent_select.c.
  */
 
-static bool run_local_tevent_select(int dummy)
+static bool run_local_tevent_poll(int dummy)
 {
 	struct tevent_context *ev;
 	struct tevent_fd *fd1, *fd2;
 	bool result = false;
 
-	ev = tevent_context_init_byname(NULL, "select");
+	ev = tevent_context_init_byname(NULL, "poll");
 	if (ev == NULL) {
 		d_fprintf(stderr, "tevent_context_init_byname failed\n");
 		goto fail;
@@ -11678,7 +11678,7 @@ static struct {
 	{ "LOCAL-sid_to_string", run_local_sid_to_string, 0},
 	{ "LOCAL-binary_to_sid", run_local_binary_to_sid, 0},
 	{ "LOCAL-DBTRANS", run_local_dbtrans, 0},
-	{ "LOCAL-TEVENT-SELECT", run_local_tevent_select, 0},
+	{ "LOCAL-TEVENT-POLL", run_local_tevent_poll, 0},
 	{ "LOCAL-CONVERT-STRING", run_local_convert_string, 0},
 	{ "LOCAL-CONV-AUTH-INFO", run_local_conv_auth_info, 0},
 	{ "LOCAL-hex_encode_buf", run_local_hex_encode_buf, 0},
@@ -11114,17 +11114,17 @@ static bool run_local_dbtrans(int dummy)
 /*
  * Just a dummy test to be run under a debugger. There's no real way
- * to inspect the tevent_select specific function from outside of
- * tevent_select.c.
+ * to inspect the tevent_poll specific function from outside of
+ * tevent_poll.c.
  */
 


-- 
Samba Shared Repository



More information about the samba-cvs mailing list